#
# Copyright 2009-2012 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#
#
# Description:    Constants definitions for vdsm and utilities.

from __future__ import absolute_import
import os

GLUSTER_MGMT_ENABLED = bool(1)

# VDSM management networks
LEGACY_MANAGEMENT_NETWORKS = ('ovirtmgmt', 'rhevm')

# SMBIOS manufacturer
SMBIOS_MANUFACTURER = 'oVirt'
SMBIOS_OSNAME = 'oVirt Node'

#
# file ownership definitions
#
VDSM_USER = 'vdsm'
VDSM_GROUP = 'kvm'
DISKIMAGE_USER = 'vdsm'
DISKIMAGE_GROUP = 'qemu'
METADATA_USER = 'vdsm'
METADATA_GROUP = 'kvm'
QEMU_PROCESS_USER = 'qemu'
QEMU_PROCESS_GROUP = 'qemu'
OVIRT_VMCONSOLE_USER = 'ovirt-vmconsole'
OVIRT_VMCONSOLE_GROUP = 'ovirt-vmconsole'


# Sanlock definitions
SANLOCK_ENABLED = 'yes' == 'yes'
SANLOCK_USER = 'sanlock'

# Libvirt selinux
LIBVIRT_SELINUX = 'yes' == 'yes'


# This is the domain version translation list
# DO NOT CHANGE OLD VALUES ONLY APPEND
DOMAIN_VERSIONS = (0, 2, 3)
SUPPORTED_BLOCKSIZE = (512,)

# This contains the domains versions that this VDSM
# accepts currently its all of the version but in the
# future we might slice it (eg. tuple(DOMAIN_VERSION[1:]))
SUPPORTED_DOMAIN_VERSIONS = DOMAIN_VERSIONS

UUID_GLOB_PATTERN = '*-*-*-*-*'

MEGAB = 2 ** 20  # = 1024 ** 2 = 1 MiB
GIB = 1024 * MEGAB

#
# Path definitions
#
P_LIBVIRT_VMCHANNELS = '/var/lib/libvirt/qemu/channels/'
P_OVIRT_VMCONSOLES = '/var/run/ovirt-vmconsole-console/'
P_VDSM = '/usr/share/vdsm/'
P_VDSM_RPC = '/usr/lib/python2.7/site-packages/vdsm/rpc/'
P_VDSM_HOOKS = '/usr/libexec/vdsm/hooks/'
P_VDSM_LIB = '/var/lib/vdsm/'
P_VDSM_RUN = '/var/run/vdsm/'
P_VDSM_STORAGE = P_VDSM_RUN + 'storage/'
P_VDSM_CONF = '/etc/vdsm/'
P_VDSM_KEYS = '/etc/pki/vdsm/keys/'
P_VDSM_CERT = '/etc/pki/vdsm/certs/vdsmcert.pem'

P_VDSM_CLIENT_LOG = '/var/run/vdsm/client.log'
P_VDSM_LOG = '/var/log/vdsm'
P_VDSM_NODE_ID = '/etc/vdsm/vdsm.id'

P_VDSM_EXEC = '/usr/libexec/vdsm'

#
# Configuration file definitions
#
SYSCONF_PATH = '/etc'

#
# External programs (sorted, please keep in order).
#
EXT_BRCTL = '/usr/sbin/brctl'

EXT_CHOWN = '/usr/bin/chown'
EXT_CP = '/usr/bin/cp'

EXT_DD = '/usr/bin/dd'
EXT_DMIDECODE = '/usr/sbin/dmidecode'
EXT_DMSETUP = '/usr/sbin/dmsetup'

EXT_FENCE_PREFIX = os.path.dirname('/usr/sbin/fence_ilo') + '/fence_'
EXT_FSCK = '/usr/sbin/fsck'
EXT_FUSER = '/usr/sbin/fuser'

EXT_GREP = '/usr/bin/grep'

EXT_IFDOWN = '/usr/sbin/ifdown'
EXT_IFUP = '/usr/sbin/ifup'
EXT_IONICE = '/usr/bin/ionice'
EXT_ISCSIADM = '/sbin/iscsiadm'
EXT_TC = '/usr/sbin/tc'

EXT_KILL = '/usr/bin/kill'

EXT_LVM = '/usr/sbin/lvm'

EXT_MKFS = '/usr/sbin/mkfs'
EXT_MKFS_MSDOS = '/usr/sbin/mkfs.msdos'
EXT_MKISOFS = '/usr/bin/mkisofs'
EXT_MK_SYSPREP_FLOPPY = '/usr/share/vdsm/mk_sysprep_floppy'
EXT_MOUNT = '/usr/bin/mount'
EXT_MULTIPATH = '/usr/sbin/multipath'

EXT_NICE = '/usr/bin/nice'

EXT_PYTHON = '/usr/bin/python'

EXT_SETSID = '/usr/bin/setsid'
EXT_SH = '/bin/sh'  # The shell path is invariable
EXT_SU = '/usr/bin/su'
EXT_SUDO = '/usr/bin/sudo'

EXT_TAR = '/usr/bin/tar'
EXT_TASKSET = '/usr/bin/taskset'
EXT_TUNE2FS = '/usr/sbin/tune2fs'

EXT_UMOUNT = '/usr/bin/umount'

EXT_SAFELEASE = '/usr/libexec/safelease/safelease'
EXT_VDSM_STORE_NET_CONFIG = '/usr/share/vdsm/vdsm-store-net-config'

EXT_CURL_IMG_WRAP = '/usr/libexec/vdsm/curl-img-wrap'
EXT_FC_SCAN = '/usr/libexec/vdsm/fc-scan'
EXT_KVM_2_OVIRT = '/usr/libexec/vdsm/kvm2ovirt'
EXT_SYSTEMD_RUN = '/usr/bin/systemd-run'
